.. _dv_api:

-----------------
DependentVariable
-----------------

.. currentmodule:: csdmpy

.. autoclass:: DependentVariable
    :show-inheritance:

    .. rubric:: Attributes Summary

    .. autosummary::
       :nosignatures:

        ~DependentVariable.type
        ~DependentVariable.description
        ~DependentVariable.application
        ~DependentVariable.name
        ~DependentVariable.unit
        ~DependentVariable.quantity_name
        ~DependentVariable.encoding
        ~DependentVariable.numeric_type
        ~DependentVariable.quantity_type
        ~DependentVariable.component_labels
        ~DependentVariable.components
        ~DependentVariable.components_url
        ~DependentVariable.axis_label
        ~DependentVariable.data_structure

    .. rubric:: Methods Summary

    .. autosummary::
       :nosignatures:

        ~DependentVariable.to
        ~DependentVariable.dict
        ~DependentVariable.to_dict
        ~DependentVariable.copy


    .. rubric:: Attributes Documentation
    .. autoattribute:: type
    .. autoattribute:: description
    .. autoattribute:: application
    .. autoattribute:: name
    .. autoattribute:: unit
    .. autoattribute:: quantity_name
    .. autoattribute:: encoding
    .. autoattribute:: numeric_type
    .. autoattribute:: quantity_type
    .. autoattribute:: component_labels
    .. autoattribute:: components
    .. autoattribute:: components_url
    .. autoattribute:: axis_label
    .. autoattribute:: data_structure


    .. rubric:: Method Documentation
    .. automethod:: to
    .. automethod:: dict
    .. automethod:: to_dict
    .. automethod:: copy
